/*
  * Arduino Uno
 * 2x DHT22 Temperature / Humidity Sensor on pin A0, A1
 * 2x relay on pin 10, 11
 * 2x hairdryers connected on the above relays
*/

#include "DHT.h"

//DHT22 sensor
#define DHTTYPE DHT22
#define DHTSensorPin1 A0
#define DHTSensorPin2 A1
#define iRelayPin1 10
#define iRelayPin2 11

#define iThresholdTemp 19 //temperature (Celsius) above which heating will stop
#define iTempDifference 3 //(lower)temperature difference at which heating will start

// Initialize DHT sensor for normal 16mhz Arduino
DHT dht1(DHTSensorPin1, DHTTYPE);
DHT dht2(DHTSensorPin2, DHTTYPE);
int iTemperatureSensorValue1, iTemperatureSensorValue2;

void setup()
{
  pinMode (iRelayPin1, OUTPUT);
  pinMode (iRelayPin2, OUTPUT);
  //on first run, the heating will be ON for 5 seconds, for testing purposes
  //if you want heating to be OFF on first run, enable the next two lines of code
  //digitalWrite (iRelayPin1, LOW);
  //digitalWrite (iRelayPin2, LOW);
  
  Serial.begin(9600);
  while (!Serial) 
  {
    ; // wait for serial port to connect. Needed for native USB port only
  }
  Serial.println ("Restart"); //serial printing only used for monitoring purposes
}

void loop()
{
  iTemperatureSensorValue1 = dht1.readTemperature();
  iTemperatureSensorValue2 = dht2.readTemperature();
  Serial.println (millis());
  Serial.println (iTemperatureSensorValue1);
  Serial.println (iTemperatureSensorValue2);
  Serial.println ("***********************");
  
  if (iTemperatureSensorValue1 > iThresholdTemp)
  {
    digitalWrite (iRelayPin1, LOW);
  }
  if (iTemperatureSensorValue1 < iThresholdTemp-iTempDifference)
  {
    digitalWrite (iRelayPin1, HIGH);
  }
  
  if (iTemperatureSensorValue2 > iThresholdTemp)
  {
    digitalWrite (iRelayPin2, LOW);
  }
  if (iTemperatureSensorValue2 < iThresholdTemp-iTempDifference)
  {
    digitalWrite (iRelayPin2, HIGH);
  }
  
  delay(5000);  
}

